<?php

$anio = date('Y');
$notifi = new App\Controladores\NotificacionesControlador();
$factu = new App\Modelos\Generico;
$woocomm = new \App\Controladores\GenericoControlador;

$nota_pendientes = [];
$factura_pendiente = [];
$pedido_empres_pendiente = [];
$presupuesto_pendiente = [];
$pedidos_woocommerce = $woocomm->woocommerce();
$notificaciones = $notifi->obtenerNotificacionesHeader();


if ($_SESSION['sucursal']['id'] != 0) {
    $sucursal = $factu->obtenerSucursales($_SESSION['sucursal']['id']);

    if ($sucursal) {
        $nota_pendientes = $factu->obtenerNotasdeEntregaAnualesPendientess("YEAR(ne.ne_fecha)=" . $anio . " AND ne.ne_surcid={$sucursal['su_id']}");
        $factura_pendiente = $factu->obtenerFacturasAnualesPendientess("YEAR(fm.fm_fecha)=" . $anio . " AND fm.fm_surcid={$sucursal['su_id']}");
        $pedido_empres_pendiente = $factu->obtenerPedidosAnualesPendientess("YEAR(pe.pe_fecha)=" . $anio . " AND pe.pe_surcid={$sucursal['su_id']}");
        $presupuesto_pendiente = $factu->obtenerPresupuestosAnualesPendientess("YEAR(pre.pre_fecha)=" . $anio . " AND pre.pre_surcid={$sucursal['su_id']}");
    }
} else {
    $nota_pendientes = $factu->obtenerNotasdeEntregaAnualesPendientess("YEAR(ne.ne_fecha)=" . $anio);
    $factura_pendiente = $factu->obtenerFacturasAnualesPendientess("YEAR(fm.fm_fecha)=" . $anio);
    $pedido_empres_pendiente = $factu->obtenerPedidosAnualesPendientess("YEAR(pe.pe_fecha)=" . $anio);
    $presupuesto_pendiente = $factu->obtenerPresupuestosAnualesPendientess("YEAR(pre.pre_fecha)=" . $anio);
}
?>
<header class="row col-12" id="appFooterptv">
    <div class="main-header">
        <a href="<?= ruta_base() ?>">
            <div class="logo-header">
                <img src="<?= ruta_base() ?>public/assets/ptv/img/pagina_gn.png" alt="navbar brand" class="navbar-brand" height="45">
            </div>
        </a>
        <nav class="navbar navbar-header navbar-expand-lg">
            <div class="container-fluid d-flex">
                <div id="search-nav" style="max-width: 200px;">
                    <span class="text-white">Sistema de Gestión Integral: PUNTO DE VENTA</span>
                </div>
                <div class="ml-10 ml-auto">
                    <div class="btn-group btn-group-sm  mr-3 p-2" role="group">
                        <a href="<?= ruta_base() ?>" title="Inicio" class="btn btn-sm btn-white text-white border">
                            <i class="fa fa-home"></i> <span class="oculto">Ir al SIG</span></a>
                        <a href="#" title="Consultar" class="btn btn-sm btn-white text-white border" data-toggle="modal" data-target="#modal-precio-global">
                            <i class="fas fa-question-circle"></i> <span class="consultar">Consultar precio</a></span>
                        <a href="#" title="Historial" class="btn btn-sm btn-white text-white border" @click.prevent="modalLineas">
                            <i class="fa fa-history"></i> <span class="oculto">En Espera</a></span>
                        <a href="<?= url('ptv'); ?>" class="btn btn-sm btn-white text-white border">
                            <i class="fa fa-plus"></i> <span class="oculto">Nuevo documento</span>
                        </a>
                        <a href="#" data-toggle="modal" data-target="#gcalc" id="messageDropdown" role="button" aria-haspopup="true" aria-expanded="false" class="btn btn-sm btn-white text-white border">
                            <i class="fa fa-calculator"></i><span class="oculto"> Calculadora</span>
                        </a>
                        <div role="group" class="btn-group dropleft">
                            <a class="btn btn-sm btn-white text-white border" href="#" id="notifDropdown" role="button" data-toggle="dropdown" aria-haspopup="true" aria-expanded="false">
                                <i class="fa fa-bell"></i>
                                <span class="notification"><?= $pedidos_woocommerce ?></span>
                            </a>
                            <ul class="dropdown-menu notif-box animated fadeIn" aria-labelledby="notifDropdown">
                                <li>
                                    <a class="see-all" href="#">
                                        <div class="dropdown-title"><span><?= $pedidos_woocommerce ?> notificaciones nuevas </span></div><i class="fa fa-angle-right text-center"></i>
                                    </a>
                                    <hr>
                                </li>
                                <li>
                                    <div class="scroll" style="height: 100%; width: 100%; padding: 0px; margin: 0px; overflow: hidden scroll;">
                                        <div class="notif-scroll scrollbar-outer">
                                            <div class="notif-center">
                                                <a href="<?php url('woocommerce') ?>">
                                                    <div class="notif-icon"><small><i class="fa fa-store"></i></small></div>
                                                    <div class="notif-content">
                                                        <span class="block">Pedidos woocommerce</span>
                                                        <span class="time"><i class="text-warning fas fa-info-circle" title="Pendiente"></i> <?= $pedidos_woocommerce ?></span>

                                                    </div>
                                                </a>
                                            </div>
                                        </div>
                                    </div>
                                </li>
                            </ul>
                        </div>
                        <a title="Calculadora" class="btn btn-sm btn-danger" href="<?php url('login/salir'); ?>">
                            Salir</a>
                    </div>
                </div>
            </div>
        </nav>
    </div>
    <?php include 'app/ptv/vista/modallineas.php' ?>
    <?php include 'app/ptv/vista/modal_precio.php'; ?>
</header>